# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: org/xrpl/rpc/v1/get_account_transaction_history.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import get_transaction_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_get__transaction__pb2
from . import account_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_account__pb2
from . import ledger_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='org/xrpl/rpc/v1/get_account_transaction_history.proto',
  package='org.xrpl.rpc.v1',
  syntax='proto3',
  serialized_options=b'\n\017org.xrpl.rpc.v1P\001',
  serialized_pb=b'\n5org/xrpl/rpc/v1/get_account_transaction_history.proto\x12\x0forg.xrpl.rpc.v1\x1a%org/xrpl/rpc/v1/get_transaction.proto\x1a\x1dorg/xrpl/rpc/v1/account.proto\x1a\x1corg/xrpl/rpc/v1/ledger.proto\"\xae\x02\n#GetAccountTransactionHistoryRequest\x12\x30\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x1f.org.xrpl.rpc.v1.AccountAddress\x12<\n\x10ledger_specifier\x18\x02 \x01(\x0b\x32 .org.xrpl.rpc.v1.LedgerSpecifierH\x00\x12\x34\n\x0cledger_range\x18\x03 \x01(\x0b\x32\x1c.org.xrpl.rpc.v1.LedgerRangeH\x00\x12\x0e\n\x06\x62inary\x18\x04 \x01(\x08\x12\x0f\n\x07\x66orward\x18\x05 \x01(\x08\x12\r\n\x05limit\x18\x06 \x01(\r\x12\'\n\x06marker\x18\x07 \x01(\x0b\x32\x17.org.xrpl.rpc.v1.MarkerB\x08\n\x06ledger\"\x96\x02\n$GetAccountTransactionHistoryResponse\x12\x30\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x1f.org.xrpl.rpc.v1.AccountAddress\x12\x18\n\x10ledger_index_min\x18\x02 \x01(\r\x12\x18\n\x10ledger_index_max\x18\x03 \x01(\r\x12\r\n\x05limit\x18\x04 \x01(\r\x12\'\n\x06marker\x18\x05 \x01(\x0b\x32\x17.org.xrpl.rpc.v1.Marker\x12=\n\x0ctransactions\x18\x06 \x03(\x0b\x32\'.org.xrpl.rpc.v1.GetTransactionResponse\x12\x11\n\tvalidated\x18\x07 \x01(\x08\"8\n\x06Marker\x12\x14\n\x0cledger_index\x18\x01 \x01(\r\x12\x18\n\x10\x61\x63\x63ount_sequence\x18\x02 \x01(\rB\x13\n\x0forg.xrpl.rpc.v1P\x01\x62\x06proto3'
  ,
  dependencies=[org_dot_xrpl_dot_rpc_dot_v1_dot_get__transaction__pb2.DESCRIPTOR,org_dot_xrpl_dot_rpc_dot_v1_dot_account__pb2.DESCRIPTOR,org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__pb2.DESCRIPTOR,])




_GETACCOUNTTRANSACTIONHISTORYREQUEST = _descriptor.Descriptor(
  name='GetAccountTransactionHistoryRequest',
  full_name='org.xrpl.rpc.v1.GetAccountTransactionHistoryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account', full_name='org.xrpl.rpc.v1.GetAccountTransactionHistoryRequest.account', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ledger_specifier', full_name='org.xrpl.rpc.v1.GetAccountTransactionHistoryRequest.ledger_specifier', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ledger_range', full_name='org.xrpl.rpc.v1.GetAccountTransactionHistoryRequest.ledger_range', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='binary', full_name='org.xrpl.rpc.v1.GetAccountTransactionHistoryRequest.binary', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='forward', full_name='org.xrpl.rpc.v1.GetAccountTransactionHistoryRequest.forward', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='org.xrpl.rpc.v1.GetAccountTransactionHistoryRequest.limit', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='marker', full_name='org.xrpl.rpc.v1.GetAccountTransactionHistoryRequest.marker', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='ledger', full_name='org.xrpl.rpc.v1.GetAccountTransactionHistoryRequest.ledger',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=175,
  serialized_end=477,
)


_GETACCOUNTTRANSACTIONHISTORYRESPONSE = _descriptor.Descriptor(
  name='GetAccountTransactionHistoryResponse',
  full_name='org.xrpl.rpc.v1.GetAccountTransactionHistoryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account', full_name='org.xrpl.rpc.v1.GetAccountTransactionHistoryResponse.account', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ledger_index_min', full_name='org.xrpl.rpc.v1.GetAccountTransactionHistoryResponse.ledger_index_min', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ledger_index_max', full_name='org.xrpl.rpc.v1.GetAccountTransactionHistoryResponse.ledger_index_max', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='org.xrpl.rpc.v1.GetAccountTransactionHistoryResponse.limit', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='marker', full_name='org.xrpl.rpc.v1.GetAccountTransactionHistoryResponse.marker', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transactions', full_name='org.xrpl.rpc.v1.GetAccountTransactionHistoryResponse.transactions', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validated', full_name='org.xrpl.rpc.v1.GetAccountTransactionHistoryResponse.validated', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=480,
  serialized_end=758,
)


_MARKER = _descriptor.Descriptor(
  name='Marker',
  full_name='org.xrpl.rpc.v1.Marker',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ledger_index', full_name='org.xrpl.rpc.v1.Marker.ledger_index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_sequence', full_name='org.xrpl.rpc.v1.Marker.account_sequence', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=760,
  serialized_end=816,
)

_GETACCOUNTTRANSACTIONHISTORYREQUEST.fields_by_name['account'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_account__pb2._ACCOUNTADDRESS
_GETACCOUNTTRANSACTIONHISTORYREQUEST.fields_by_name['ledger_specifier'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__pb2._LEDGERSPECIFIER
_GETACCOUNTTRANSACTIONHISTORYREQUEST.fields_by_name['ledger_range'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__pb2._LEDGERRANGE
_GETACCOUNTTRANSACTIONHISTORYREQUEST.fields_by_name['marker'].message_type = _MARKER
_GETACCOUNTTRANSACTIONHISTORYREQUEST.oneofs_by_name['ledger'].fields.append(
  _GETACCOUNTTRANSACTIONHISTORYREQUEST.fields_by_name['ledger_specifier'])
_GETACCOUNTTRANSACTIONHISTORYREQUEST.fields_by_name['ledger_specifier'].containing_oneof = _GETACCOUNTTRANSACTIONHISTORYREQUEST.oneofs_by_name['ledger']
_GETACCOUNTTRANSACTIONHISTORYREQUEST.oneofs_by_name['ledger'].fields.append(
  _GETACCOUNTTRANSACTIONHISTORYREQUEST.fields_by_name['ledger_range'])
_GETACCOUNTTRANSACTIONHISTORYREQUEST.fields_by_name['ledger_range'].containing_oneof = _GETACCOUNTTRANSACTIONHISTORYREQUEST.oneofs_by_name['ledger']
_GETACCOUNTTRANSACTIONHISTORYRESPONSE.fields_by_name['account'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_account__pb2._ACCOUNTADDRESS
_GETACCOUNTTRANSACTIONHISTORYRESPONSE.fields_by_name['marker'].message_type = _MARKER
_GETACCOUNTTRANSACTIONHISTORYRESPONSE.fields_by_name['transactions'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_get__transaction__pb2._GETTRANSACTIONRESPONSE
DESCRIPTOR.message_types_by_name['GetAccountTransactionHistoryRequest'] = _GETACCOUNTTRANSACTIONHISTORYREQUEST
DESCRIPTOR.message_types_by_name['GetAccountTransactionHistoryResponse'] = _GETACCOUNTTRANSACTIONHISTORYRESPONSE
DESCRIPTOR.message_types_by_name['Marker'] = _MARKER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetAccountTransactionHistoryRequest = _reflection.GeneratedProtocolMessageType('GetAccountTransactionHistoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETACCOUNTTRANSACTIONHISTORYREQUEST,
  '__module__' : 'org.xrpl.rpc.v1.get_account_transaction_history_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.GetAccountTransactionHistoryRequest)
  })
_sym_db.RegisterMessage(GetAccountTransactionHistoryRequest)

GetAccountTransactionHistoryResponse = _reflection.GeneratedProtocolMessageType('GetAccountTransactionHistoryResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETACCOUNTTRANSACTIONHISTORYRESPONSE,
  '__module__' : 'org.xrpl.rpc.v1.get_account_transaction_history_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.GetAccountTransactionHistoryResponse)
  })
_sym_db.RegisterMessage(GetAccountTransactionHistoryResponse)

Marker = _reflection.GeneratedProtocolMessageType('Marker', (_message.Message,), {
  'DESCRIPTOR' : _MARKER,
  '__module__' : 'org.xrpl.rpc.v1.get_account_transaction_history_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.Marker)
  })
_sym_db.RegisterMessage(Marker)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
