# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    Iterable as typing___Iterable,
    List as typing___List,
    NewType as typing___NewType,
    Optional as typing___Optional,
    Tuple as typing___Tuple,
    Union as typing___Union,
    cast as typing___cast,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int
builtin___str = str
if sys.version_info < (3,):
    builtin___buffer = buffer
    builtin___unicode = unicode


DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class LedgerSpecifier(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ShortcutValue = typing___NewType('ShortcutValue', builtin___int)
    type___ShortcutValue = ShortcutValue
    class Shortcut(object):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: builtin___int) -> builtin___str: ...
        @classmethod
        def Value(cls, name: builtin___str) -> LedgerSpecifier.ShortcutValue: ...
        @classmethod
        def keys(cls) -> typing___List[builtin___str]: ...
        @classmethod
        def values(cls) -> typing___List[LedgerSpecifier.ShortcutValue]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[builtin___str, LedgerSpecifier.ShortcutValue]]: ...
        SHORTCUT_UNSPECIFIED = typing___cast(LedgerSpecifier.ShortcutValue, 0)
        SHORTCUT_VALIDATED = typing___cast(LedgerSpecifier.ShortcutValue, 1)
        SHORTCUT_CLOSED = typing___cast(LedgerSpecifier.ShortcutValue, 2)
        SHORTCUT_CURRENT = typing___cast(LedgerSpecifier.ShortcutValue, 3)
    SHORTCUT_UNSPECIFIED = typing___cast(LedgerSpecifier.ShortcutValue, 0)
    SHORTCUT_VALIDATED = typing___cast(LedgerSpecifier.ShortcutValue, 1)
    SHORTCUT_CLOSED = typing___cast(LedgerSpecifier.ShortcutValue, 2)
    SHORTCUT_CURRENT = typing___cast(LedgerSpecifier.ShortcutValue, 3)
    type___Shortcut = Shortcut

    shortcut: type___LedgerSpecifier.ShortcutValue = ...
    sequence: builtin___int = ...
    hash: builtin___bytes = ...

    def __init__(self,
        *,
        shortcut : typing___Optional[type___LedgerSpecifier.ShortcutValue] = None,
        sequence : typing___Optional[builtin___int] = None,
        hash : typing___Optional[builtin___bytes] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> LedgerSpecifier: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> LedgerSpecifier: ...
    def HasField(self, field_name: typing_extensions___Literal[u"hash",b"hash",u"ledger",b"ledger",u"sequence",b"sequence",u"shortcut",b"shortcut"]) -> builtin___bool: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"hash",b"hash",u"ledger",b"ledger",u"sequence",b"sequence",u"shortcut",b"shortcut"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"ledger",b"ledger"]) -> typing_extensions___Literal["shortcut","sequence","hash"]: ...
type___LedgerSpecifier = LedgerSpecifier

class LedgerRange(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ledger_index_min: builtin___int = ...
    ledger_index_max: builtin___int = ...

    def __init__(self,
        *,
        ledger_index_min : typing___Optional[builtin___int] = None,
        ledger_index_max : typing___Optional[builtin___int] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> LedgerRange: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> LedgerRange: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"ledger_index_max",b"ledger_index_max",u"ledger_index_min",b"ledger_index_min"]) -> None: ...
type___LedgerRange = LedgerRange

class RawLedgerObject(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ModificationTypeValue = typing___NewType('ModificationTypeValue', builtin___int)
    type___ModificationTypeValue = ModificationTypeValue
    class ModificationType(object):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: builtin___int) -> builtin___str: ...
        @classmethod
        def Value(cls, name: builtin___str) -> RawLedgerObject.ModificationTypeValue: ...
        @classmethod
        def keys(cls) -> typing___List[builtin___str]: ...
        @classmethod
        def values(cls) -> typing___List[RawLedgerObject.ModificationTypeValue]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[builtin___str, RawLedgerObject.ModificationTypeValue]]: ...
        UNSPECIFIED = typing___cast(RawLedgerObject.ModificationTypeValue, 0)
        CREATED = typing___cast(RawLedgerObject.ModificationTypeValue, 1)
        MODIFIED = typing___cast(RawLedgerObject.ModificationTypeValue, 2)
        DELETED = typing___cast(RawLedgerObject.ModificationTypeValue, 3)
    UNSPECIFIED = typing___cast(RawLedgerObject.ModificationTypeValue, 0)
    CREATED = typing___cast(RawLedgerObject.ModificationTypeValue, 1)
    MODIFIED = typing___cast(RawLedgerObject.ModificationTypeValue, 2)
    DELETED = typing___cast(RawLedgerObject.ModificationTypeValue, 3)
    type___ModificationType = ModificationType

    data: builtin___bytes = ...
    key: builtin___bytes = ...
    mod_type: type___RawLedgerObject.ModificationTypeValue = ...
    predecessor: builtin___bytes = ...
    successor: builtin___bytes = ...

    def __init__(self,
        *,
        data : typing___Optional[builtin___bytes] = None,
        key : typing___Optional[builtin___bytes] = None,
        mod_type : typing___Optional[type___RawLedgerObject.ModificationTypeValue] = None,
        predecessor : typing___Optional[builtin___bytes] = None,
        successor : typing___Optional[builtin___bytes] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> RawLedgerObject: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> RawLedgerObject: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"data",b"data",u"key",b"key",u"mod_type",b"mod_type",u"predecessor",b"predecessor",u"successor",b"successor"]) -> None: ...
type___RawLedgerObject = RawLedgerObject

class RawLedgerObjects(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def objects(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[type___RawLedgerObject]: ...

    def __init__(self,
        *,
        objects : typing___Optional[typing___Iterable[type___RawLedgerObject]] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> RawLedgerObjects: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> RawLedgerObjects: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"objects",b"objects"]) -> None: ...
type___RawLedgerObjects = RawLedgerObjects

class BookSuccessor(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    book_base: builtin___bytes = ...
    first_book: builtin___bytes = ...

    def __init__(self,
        *,
        book_base : typing___Optional[builtin___bytes] = None,
        first_book : typing___Optional[builtin___bytes] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> BookSuccessor: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> BookSuccessor: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"book_base",b"book_base",u"first_book",b"first_book"]) -> None: ...
type___BookSuccessor = BookSuccessor
