# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: org/xrpl/rpc/v1/submit.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import meta_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_meta__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='org/xrpl/rpc/v1/submit.proto',
  package='org.xrpl.rpc.v1',
  syntax='proto3',
  serialized_options=b'\n\017org.xrpl.rpc.v1P\001',
  serialized_pb=b'\n\x1corg/xrpl/rpc/v1/submit.proto\x12\x0forg.xrpl.rpc.v1\x1a\x1aorg/xrpl/rpc/v1/meta.proto\"\\\n\x18SubmitTransactionRequest\x12\x1a\n\x12signed_transaction\x18\x01 \x01(\x0c\x12\x11\n\tfail_hard\x18\x02 \x01(\x08\x12\x11\n\tclient_ip\x18\x03 \x01(\t\"\x9f\x01\n\x19SubmitTransactionResponse\x12\x39\n\rengine_result\x18\x01 \x01(\x0b\x32\".org.xrpl.rpc.v1.TransactionResult\x12\x1a\n\x12\x65ngine_result_code\x18\x02 \x01(\x03\x12\x1d\n\x15\x65ngine_result_message\x18\x03 \x01(\t\x12\x0c\n\x04hash\x18\x04 \x01(\x0c\x42\x13\n\x0forg.xrpl.rpc.v1P\x01\x62\x06proto3'
  ,
  dependencies=[org_dot_xrpl_dot_rpc_dot_v1_dot_meta__pb2.DESCRIPTOR,])




_SUBMITTRANSACTIONREQUEST = _descriptor.Descriptor(
  name='SubmitTransactionRequest',
  full_name='org.xrpl.rpc.v1.SubmitTransactionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='signed_transaction', full_name='org.xrpl.rpc.v1.SubmitTransactionRequest.signed_transaction', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fail_hard', full_name='org.xrpl.rpc.v1.SubmitTransactionRequest.fail_hard', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_ip', full_name='org.xrpl.rpc.v1.SubmitTransactionRequest.client_ip', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=77,
  serialized_end=169,
)


_SUBMITTRANSACTIONRESPONSE = _descriptor.Descriptor(
  name='SubmitTransactionResponse',
  full_name='org.xrpl.rpc.v1.SubmitTransactionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='engine_result', full_name='org.xrpl.rpc.v1.SubmitTransactionResponse.engine_result', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='engine_result_code', full_name='org.xrpl.rpc.v1.SubmitTransactionResponse.engine_result_code', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='engine_result_message', full_name='org.xrpl.rpc.v1.SubmitTransactionResponse.engine_result_message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hash', full_name='org.xrpl.rpc.v1.SubmitTransactionResponse.hash', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=172,
  serialized_end=331,
)

_SUBMITTRANSACTIONRESPONSE.fields_by_name['engine_result'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_meta__pb2._TRANSACTIONRESULT
DESCRIPTOR.message_types_by_name['SubmitTransactionRequest'] = _SUBMITTRANSACTIONREQUEST
DESCRIPTOR.message_types_by_name['SubmitTransactionResponse'] = _SUBMITTRANSACTIONRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SubmitTransactionRequest = _reflection.GeneratedProtocolMessageType('SubmitTransactionRequest', (_message.Message,), {
  'DESCRIPTOR' : _SUBMITTRANSACTIONREQUEST,
  '__module__' : 'org.xrpl.rpc.v1.submit_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.SubmitTransactionRequest)
  })
_sym_db.RegisterMessage(SubmitTransactionRequest)

SubmitTransactionResponse = _reflection.GeneratedProtocolMessageType('SubmitTransactionResponse', (_message.Message,), {
  'DESCRIPTOR' : _SUBMITTRANSACTIONRESPONSE,
  '__module__' : 'org.xrpl.rpc.v1.submit_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.SubmitTransactionResponse)
  })
_sym_db.RegisterMessage(SubmitTransactionResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
