# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: org/xrpl/rpc/v1/ledger.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='org/xrpl/rpc/v1/ledger.proto',
  package='org.xrpl.rpc.v1',
  syntax='proto3',
  serialized_options=b'\n\017org.xrpl.rpc.v1P\001',
  serialized_pb=b'\n\x1corg/xrpl/rpc/v1/ledger.proto\x12\x0forg.xrpl.rpc.v1\"\xe7\x01\n\x0fLedgerSpecifier\x12=\n\x08shortcut\x18\x01 \x01(\x0e\x32).org.xrpl.rpc.v1.LedgerSpecifier.ShortcutH\x00\x12\x12\n\x08sequence\x18\x02 \x01(\rH\x00\x12\x0e\n\x04hash\x18\x03 \x01(\x0cH\x00\"g\n\x08Shortcut\x12\x18\n\x14SHORTCUT_UNSPECIFIED\x10\x00\x12\x16\n\x12SHORTCUT_VALIDATED\x10\x01\x12\x13\n\x0fSHORTCUT_CLOSED\x10\x02\x12\x14\n\x10SHORTCUT_CURRENT\x10\x03\x42\x08\n\x06ledger\"A\n\x0bLedgerRange\x12\x18\n\x10ledger_index_min\x18\x01 \x01(\r\x12\x18\n\x10ledger_index_max\x18\x02 \x01(\r\"\xe6\x01\n\x0fRawLedgerObject\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\x0b\n\x03key\x18\x02 \x01(\x0c\x12\x43\n\x08mod_type\x18\x03 \x01(\x0e\x32\x31.org.xrpl.rpc.v1.RawLedgerObject.ModificationType\x12\x13\n\x0bpredecessor\x18\x04 \x01(\x0c\x12\x11\n\tsuccessor\x18\x05 \x01(\x0c\"K\n\x10ModificationType\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07\x43REATED\x10\x01\x12\x0c\n\x08MODIFIED\x10\x02\x12\x0b\n\x07\x44\x45LETED\x10\x03\"E\n\x10RawLedgerObjects\x12\x31\n\x07objects\x18\x01 \x03(\x0b\x32 .org.xrpl.rpc.v1.RawLedgerObject\"6\n\rBookSuccessor\x12\x11\n\tbook_base\x18\x01 \x01(\x0c\x12\x12\n\nfirst_book\x18\x02 \x01(\x0c\x42\x13\n\x0forg.xrpl.rpc.v1P\x01\x62\x06proto3'
)



_LEDGERSPECIFIER_SHORTCUT = _descriptor.EnumDescriptor(
  name='Shortcut',
  full_name='org.xrpl.rpc.v1.LedgerSpecifier.Shortcut',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SHORTCUT_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SHORTCUT_VALIDATED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SHORTCUT_CLOSED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SHORTCUT_CURRENT', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=168,
  serialized_end=271,
)
_sym_db.RegisterEnumDescriptor(_LEDGERSPECIFIER_SHORTCUT)

_RAWLEDGEROBJECT_MODIFICATIONTYPE = _descriptor.EnumDescriptor(
  name='ModificationType',
  full_name='org.xrpl.rpc.v1.RawLedgerObject.ModificationType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CREATED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODIFIED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DELETED', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=506,
  serialized_end=581,
)
_sym_db.RegisterEnumDescriptor(_RAWLEDGEROBJECT_MODIFICATIONTYPE)


_LEDGERSPECIFIER = _descriptor.Descriptor(
  name='LedgerSpecifier',
  full_name='org.xrpl.rpc.v1.LedgerSpecifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='shortcut', full_name='org.xrpl.rpc.v1.LedgerSpecifier.shortcut', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sequence', full_name='org.xrpl.rpc.v1.LedgerSpecifier.sequence', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hash', full_name='org.xrpl.rpc.v1.LedgerSpecifier.hash', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LEDGERSPECIFIER_SHORTCUT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='ledger', full_name='org.xrpl.rpc.v1.LedgerSpecifier.ledger',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=50,
  serialized_end=281,
)


_LEDGERRANGE = _descriptor.Descriptor(
  name='LedgerRange',
  full_name='org.xrpl.rpc.v1.LedgerRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ledger_index_min', full_name='org.xrpl.rpc.v1.LedgerRange.ledger_index_min', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ledger_index_max', full_name='org.xrpl.rpc.v1.LedgerRange.ledger_index_max', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=283,
  serialized_end=348,
)


_RAWLEDGEROBJECT = _descriptor.Descriptor(
  name='RawLedgerObject',
  full_name='org.xrpl.rpc.v1.RawLedgerObject',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='org.xrpl.rpc.v1.RawLedgerObject.data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='key', full_name='org.xrpl.rpc.v1.RawLedgerObject.key', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mod_type', full_name='org.xrpl.rpc.v1.RawLedgerObject.mod_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='predecessor', full_name='org.xrpl.rpc.v1.RawLedgerObject.predecessor', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='successor', full_name='org.xrpl.rpc.v1.RawLedgerObject.successor', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _RAWLEDGEROBJECT_MODIFICATIONTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=351,
  serialized_end=581,
)


_RAWLEDGEROBJECTS = _descriptor.Descriptor(
  name='RawLedgerObjects',
  full_name='org.xrpl.rpc.v1.RawLedgerObjects',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='objects', full_name='org.xrpl.rpc.v1.RawLedgerObjects.objects', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=583,
  serialized_end=652,
)


_BOOKSUCCESSOR = _descriptor.Descriptor(
  name='BookSuccessor',
  full_name='org.xrpl.rpc.v1.BookSuccessor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='book_base', full_name='org.xrpl.rpc.v1.BookSuccessor.book_base', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='first_book', full_name='org.xrpl.rpc.v1.BookSuccessor.first_book', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=654,
  serialized_end=708,
)

_LEDGERSPECIFIER.fields_by_name['shortcut'].enum_type = _LEDGERSPECIFIER_SHORTCUT
_LEDGERSPECIFIER_SHORTCUT.containing_type = _LEDGERSPECIFIER
_LEDGERSPECIFIER.oneofs_by_name['ledger'].fields.append(
  _LEDGERSPECIFIER.fields_by_name['shortcut'])
_LEDGERSPECIFIER.fields_by_name['shortcut'].containing_oneof = _LEDGERSPECIFIER.oneofs_by_name['ledger']
_LEDGERSPECIFIER.oneofs_by_name['ledger'].fields.append(
  _LEDGERSPECIFIER.fields_by_name['sequence'])
_LEDGERSPECIFIER.fields_by_name['sequence'].containing_oneof = _LEDGERSPECIFIER.oneofs_by_name['ledger']
_LEDGERSPECIFIER.oneofs_by_name['ledger'].fields.append(
  _LEDGERSPECIFIER.fields_by_name['hash'])
_LEDGERSPECIFIER.fields_by_name['hash'].containing_oneof = _LEDGERSPECIFIER.oneofs_by_name['ledger']
_RAWLEDGEROBJECT.fields_by_name['mod_type'].enum_type = _RAWLEDGEROBJECT_MODIFICATIONTYPE
_RAWLEDGEROBJECT_MODIFICATIONTYPE.containing_type = _RAWLEDGEROBJECT
_RAWLEDGEROBJECTS.fields_by_name['objects'].message_type = _RAWLEDGEROBJECT
DESCRIPTOR.message_types_by_name['LedgerSpecifier'] = _LEDGERSPECIFIER
DESCRIPTOR.message_types_by_name['LedgerRange'] = _LEDGERRANGE
DESCRIPTOR.message_types_by_name['RawLedgerObject'] = _RAWLEDGEROBJECT
DESCRIPTOR.message_types_by_name['RawLedgerObjects'] = _RAWLEDGEROBJECTS
DESCRIPTOR.message_types_by_name['BookSuccessor'] = _BOOKSUCCESSOR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LedgerSpecifier = _reflection.GeneratedProtocolMessageType('LedgerSpecifier', (_message.Message,), {
  'DESCRIPTOR' : _LEDGERSPECIFIER,
  '__module__' : 'org.xrpl.rpc.v1.ledger_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.LedgerSpecifier)
  })
_sym_db.RegisterMessage(LedgerSpecifier)

LedgerRange = _reflection.GeneratedProtocolMessageType('LedgerRange', (_message.Message,), {
  'DESCRIPTOR' : _LEDGERRANGE,
  '__module__' : 'org.xrpl.rpc.v1.ledger_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.LedgerRange)
  })
_sym_db.RegisterMessage(LedgerRange)

RawLedgerObject = _reflection.GeneratedProtocolMessageType('RawLedgerObject', (_message.Message,), {
  'DESCRIPTOR' : _RAWLEDGEROBJECT,
  '__module__' : 'org.xrpl.rpc.v1.ledger_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.RawLedgerObject)
  })
_sym_db.RegisterMessage(RawLedgerObject)

RawLedgerObjects = _reflection.GeneratedProtocolMessageType('RawLedgerObjects', (_message.Message,), {
  'DESCRIPTOR' : _RAWLEDGEROBJECTS,
  '__module__' : 'org.xrpl.rpc.v1.ledger_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.RawLedgerObjects)
  })
_sym_db.RegisterMessage(RawLedgerObjects)

BookSuccessor = _reflection.GeneratedProtocolMessageType('BookSuccessor', (_message.Message,), {
  'DESCRIPTOR' : _BOOKSUCCESSOR,
  '__module__' : 'org.xrpl.rpc.v1.ledger_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.BookSuccessor)
  })
_sym_db.RegisterMessage(BookSuccessor)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
