# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: org/xrpl/rpc/v1/get_ledger_data.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import ledger_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='org/xrpl/rpc/v1/get_ledger_data.proto',
  package='org.xrpl.rpc.v1',
  syntax='proto3',
  serialized_options=b'\n\017org.xrpl.rpc.v1P\001',
  serialized_pb=b'\n%org/xrpl/rpc/v1/get_ledger_data.proto\x12\x0forg.xrpl.rpc.v1\x1a\x1corg/xrpl/rpc/v1/ledger.proto\"\x8d\x01\n\x14GetLedgerDataRequest\x12\x0e\n\x06marker\x18\x01 \x01(\x0c\x12\x30\n\x06ledger\x18\x02 \x01(\x0b\x32 .org.xrpl.rpc.v1.LedgerSpecifier\x12\x12\n\nend_marker\x18\x03 \x01(\x0c\x12\x11\n\tclient_ip\x18\x04 \x01(\t\x12\x0c\n\x04user\x18\x06 \x01(\t\"\xa3\x01\n\x15GetLedgerDataResponse\x12\x14\n\x0cledger_index\x18\x01 \x01(\r\x12\x13\n\x0bledger_hash\x18\x02 \x01(\x0c\x12\x39\n\x0eledger_objects\x18\x03 \x01(\x0b\x32!.org.xrpl.rpc.v1.RawLedgerObjects\x12\x0e\n\x06marker\x18\x04 \x01(\x0c\x12\x14\n\x0cis_unlimited\x18\x07 \x01(\x08\x42\x13\n\x0forg.xrpl.rpc.v1P\x01\x62\x06proto3'
  ,
  dependencies=[org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__pb2.DESCRIPTOR,])




_GETLEDGERDATAREQUEST = _descriptor.Descriptor(
  name='GetLedgerDataRequest',
  full_name='org.xrpl.rpc.v1.GetLedgerDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='marker', full_name='org.xrpl.rpc.v1.GetLedgerDataRequest.marker', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ledger', full_name='org.xrpl.rpc.v1.GetLedgerDataRequest.ledger', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_marker', full_name='org.xrpl.rpc.v1.GetLedgerDataRequest.end_marker', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_ip', full_name='org.xrpl.rpc.v1.GetLedgerDataRequest.client_ip', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user', full_name='org.xrpl.rpc.v1.GetLedgerDataRequest.user', index=4,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=89,
  serialized_end=230,
)


_GETLEDGERDATARESPONSE = _descriptor.Descriptor(
  name='GetLedgerDataResponse',
  full_name='org.xrpl.rpc.v1.GetLedgerDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ledger_index', full_name='org.xrpl.rpc.v1.GetLedgerDataResponse.ledger_index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ledger_hash', full_name='org.xrpl.rpc.v1.GetLedgerDataResponse.ledger_hash', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ledger_objects', full_name='org.xrpl.rpc.v1.GetLedgerDataResponse.ledger_objects', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='marker', full_name='org.xrpl.rpc.v1.GetLedgerDataResponse.marker', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_unlimited', full_name='org.xrpl.rpc.v1.GetLedgerDataResponse.is_unlimited', index=4,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=233,
  serialized_end=396,
)

_GETLEDGERDATAREQUEST.fields_by_name['ledger'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__pb2._LEDGERSPECIFIER
_GETLEDGERDATARESPONSE.fields_by_name['ledger_objects'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__pb2._RAWLEDGEROBJECTS
DESCRIPTOR.message_types_by_name['GetLedgerDataRequest'] = _GETLEDGERDATAREQUEST
DESCRIPTOR.message_types_by_name['GetLedgerDataResponse'] = _GETLEDGERDATARESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetLedgerDataRequest = _reflection.GeneratedProtocolMessageType('GetLedgerDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLEDGERDATAREQUEST,
  '__module__' : 'org.xrpl.rpc.v1.get_ledger_data_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.GetLedgerDataRequest)
  })
_sym_db.RegisterMessage(GetLedgerDataRequest)

GetLedgerDataResponse = _reflection.GeneratedProtocolMessageType('GetLedgerDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETLEDGERDATARESPONSE,
  '__module__' : 'org.xrpl.rpc.v1.get_ledger_data_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.GetLedgerDataResponse)
  })
_sym_db.RegisterMessage(GetLedgerDataResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
