# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: org/xrpl/rpc/v1/get_ledger.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import ledger_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='org/xrpl/rpc/v1/get_ledger.proto',
  package='org.xrpl.rpc.v1',
  syntax='proto3',
  serialized_options=b'\n\017org.xrpl.rpc.v1P\001',
  serialized_pb=b'\n org/xrpl/rpc/v1/get_ledger.proto\x12\x0forg.xrpl.rpc.v1\x1a\x1corg/xrpl/rpc/v1/ledger.proto\"\xbe\x01\n\x10GetLedgerRequest\x12\x30\n\x06ledger\x18\x01 \x01(\x0b\x32 .org.xrpl.rpc.v1.LedgerSpecifier\x12\x14\n\x0ctransactions\x18\x02 \x01(\x08\x12\x0e\n\x06\x65xpand\x18\x03 \x01(\x08\x12\x13\n\x0bget_objects\x18\x04 \x01(\x08\x12\x11\n\tclient_ip\x18\x05 \x01(\t\x12\x0c\n\x04user\x18\x06 \x01(\t\x12\x1c\n\x14get_object_neighbors\x18\x07 \x01(\x08\"\xb6\x03\n\x11GetLedgerResponse\x12\x15\n\rledger_header\x18\x01 \x01(\x0c\x12;\n\x0bhashes_list\x18\x02 \x01(\x0b\x32$.org.xrpl.rpc.v1.TransactionHashListH\x00\x12H\n\x11transactions_list\x18\x03 \x01(\x0b\x32+.org.xrpl.rpc.v1.TransactionAndMetadataListH\x00\x12\x11\n\tvalidated\x18\x04 \x01(\x08\x12\x39\n\x0eledger_objects\x18\x05 \x01(\x0b\x32!.org.xrpl.rpc.v1.RawLedgerObjects\x12\x19\n\x11skiplist_included\x18\x06 \x01(\x08\x12\x14\n\x0cis_unlimited\x18\x07 \x01(\x08\x12\x18\n\x10objects_included\x18\x08 \x01(\x08\x12!\n\x19object_neighbors_included\x18\t \x01(\x08\x12\x37\n\x0f\x62ook_successors\x18\n \x03(\x0b\x32\x1e.org.xrpl.rpc.v1.BookSuccessorB\x0e\n\x0ctransactions\"%\n\x13TransactionHashList\x12\x0e\n\x06hashes\x18\x01 \x03(\x0c\"I\n\x16TransactionAndMetadata\x12\x18\n\x10transaction_blob\x18\x01 \x01(\x0c\x12\x15\n\rmetadata_blob\x18\x02 \x01(\x0c\"[\n\x1aTransactionAndMetadataList\x12=\n\x0ctransactions\x18\x01 \x03(\x0b\x32\'.org.xrpl.rpc.v1.TransactionAndMetadataB\x13\n\x0forg.xrpl.rpc.v1P\x01\x62\x06proto3'
  ,
  dependencies=[org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__pb2.DESCRIPTOR,])




_GETLEDGERREQUEST = _descriptor.Descriptor(
  name='GetLedgerRequest',
  full_name='org.xrpl.rpc.v1.GetLedgerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ledger', full_name='org.xrpl.rpc.v1.GetLedgerRequest.ledger', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transactions', full_name='org.xrpl.rpc.v1.GetLedgerRequest.transactions', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expand', full_name='org.xrpl.rpc.v1.GetLedgerRequest.expand', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='get_objects', full_name='org.xrpl.rpc.v1.GetLedgerRequest.get_objects', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_ip', full_name='org.xrpl.rpc.v1.GetLedgerRequest.client_ip', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user', full_name='org.xrpl.rpc.v1.GetLedgerRequest.user', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='get_object_neighbors', full_name='org.xrpl.rpc.v1.GetLedgerRequest.get_object_neighbors', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=84,
  serialized_end=274,
)


_GETLEDGERRESPONSE = _descriptor.Descriptor(
  name='GetLedgerResponse',
  full_name='org.xrpl.rpc.v1.GetLedgerResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ledger_header', full_name='org.xrpl.rpc.v1.GetLedgerResponse.ledger_header', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hashes_list', full_name='org.xrpl.rpc.v1.GetLedgerResponse.hashes_list', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transactions_list', full_name='org.xrpl.rpc.v1.GetLedgerResponse.transactions_list', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validated', full_name='org.xrpl.rpc.v1.GetLedgerResponse.validated', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ledger_objects', full_name='org.xrpl.rpc.v1.GetLedgerResponse.ledger_objects', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='skiplist_included', full_name='org.xrpl.rpc.v1.GetLedgerResponse.skiplist_included', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_unlimited', full_name='org.xrpl.rpc.v1.GetLedgerResponse.is_unlimited', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='objects_included', full_name='org.xrpl.rpc.v1.GetLedgerResponse.objects_included', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='object_neighbors_included', full_name='org.xrpl.rpc.v1.GetLedgerResponse.object_neighbors_included', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='book_successors', full_name='org.xrpl.rpc.v1.GetLedgerResponse.book_successors', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='transactions', full_name='org.xrpl.rpc.v1.GetLedgerResponse.transactions',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=277,
  serialized_end=715,
)


_TRANSACTIONHASHLIST = _descriptor.Descriptor(
  name='TransactionHashList',
  full_name='org.xrpl.rpc.v1.TransactionHashList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hashes', full_name='org.xrpl.rpc.v1.TransactionHashList.hashes', index=0,
      number=1, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=717,
  serialized_end=754,
)


_TRANSACTIONANDMETADATA = _descriptor.Descriptor(
  name='TransactionAndMetadata',
  full_name='org.xrpl.rpc.v1.TransactionAndMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transaction_blob', full_name='org.xrpl.rpc.v1.TransactionAndMetadata.transaction_blob', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata_blob', full_name='org.xrpl.rpc.v1.TransactionAndMetadata.metadata_blob', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=756,
  serialized_end=829,
)


_TRANSACTIONANDMETADATALIST = _descriptor.Descriptor(
  name='TransactionAndMetadataList',
  full_name='org.xrpl.rpc.v1.TransactionAndMetadataList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transactions', full_name='org.xrpl.rpc.v1.TransactionAndMetadataList.transactions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=831,
  serialized_end=922,
)

_GETLEDGERREQUEST.fields_by_name['ledger'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__pb2._LEDGERSPECIFIER
_GETLEDGERRESPONSE.fields_by_name['hashes_list'].message_type = _TRANSACTIONHASHLIST
_GETLEDGERRESPONSE.fields_by_name['transactions_list'].message_type = _TRANSACTIONANDMETADATALIST
_GETLEDGERRESPONSE.fields_by_name['ledger_objects'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__pb2._RAWLEDGEROBJECTS
_GETLEDGERRESPONSE.fields_by_name['book_successors'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__pb2._BOOKSUCCESSOR
_GETLEDGERRESPONSE.oneofs_by_name['transactions'].fields.append(
  _GETLEDGERRESPONSE.fields_by_name['hashes_list'])
_GETLEDGERRESPONSE.fields_by_name['hashes_list'].containing_oneof = _GETLEDGERRESPONSE.oneofs_by_name['transactions']
_GETLEDGERRESPONSE.oneofs_by_name['transactions'].fields.append(
  _GETLEDGERRESPONSE.fields_by_name['transactions_list'])
_GETLEDGERRESPONSE.fields_by_name['transactions_list'].containing_oneof = _GETLEDGERRESPONSE.oneofs_by_name['transactions']
_TRANSACTIONANDMETADATALIST.fields_by_name['transactions'].message_type = _TRANSACTIONANDMETADATA
DESCRIPTOR.message_types_by_name['GetLedgerRequest'] = _GETLEDGERREQUEST
DESCRIPTOR.message_types_by_name['GetLedgerResponse'] = _GETLEDGERRESPONSE
DESCRIPTOR.message_types_by_name['TransactionHashList'] = _TRANSACTIONHASHLIST
DESCRIPTOR.message_types_by_name['TransactionAndMetadata'] = _TRANSACTIONANDMETADATA
DESCRIPTOR.message_types_by_name['TransactionAndMetadataList'] = _TRANSACTIONANDMETADATALIST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetLedgerRequest = _reflection.GeneratedProtocolMessageType('GetLedgerRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLEDGERREQUEST,
  '__module__' : 'org.xrpl.rpc.v1.get_ledger_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.GetLedgerRequest)
  })
_sym_db.RegisterMessage(GetLedgerRequest)

GetLedgerResponse = _reflection.GeneratedProtocolMessageType('GetLedgerResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETLEDGERRESPONSE,
  '__module__' : 'org.xrpl.rpc.v1.get_ledger_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.GetLedgerResponse)
  })
_sym_db.RegisterMessage(GetLedgerResponse)

TransactionHashList = _reflection.GeneratedProtocolMessageType('TransactionHashList', (_message.Message,), {
  'DESCRIPTOR' : _TRANSACTIONHASHLIST,
  '__module__' : 'org.xrpl.rpc.v1.get_ledger_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.TransactionHashList)
  })
_sym_db.RegisterMessage(TransactionHashList)

TransactionAndMetadata = _reflection.GeneratedProtocolMessageType('TransactionAndMetadata', (_message.Message,), {
  'DESCRIPTOR' : _TRANSACTIONANDMETADATA,
  '__module__' : 'org.xrpl.rpc.v1.get_ledger_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.TransactionAndMetadata)
  })
_sym_db.RegisterMessage(TransactionAndMetadata)

TransactionAndMetadataList = _reflection.GeneratedProtocolMessageType('TransactionAndMetadataList', (_message.Message,), {
  'DESCRIPTOR' : _TRANSACTIONANDMETADATALIST,
  '__module__' : 'org.xrpl.rpc.v1.get_ledger_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.TransactionAndMetadataList)
  })
_sym_db.RegisterMessage(TransactionAndMetadataList)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
