# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: org/xrpl/rpc/v1/get_transaction.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import meta_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_meta__pb2
from . import ledger_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__pb2
from . import transaction_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_transaction__pb2
from . import common_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='org/xrpl/rpc/v1/get_transaction.proto',
  package='org.xrpl.rpc.v1',
  syntax='proto3',
  serialized_options=b'\n\017org.xrpl.rpc.v1P\001',
  serialized_pb=b'\n%org/xrpl/rpc/v1/get_transaction.proto\x12\x0forg.xrpl.rpc.v1\x1a\x1aorg/xrpl/rpc/v1/meta.proto\x1a\x1corg/xrpl/rpc/v1/ledger.proto\x1a!org/xrpl/rpc/v1/transaction.proto\x1a\x1corg/xrpl/rpc/v1/common.proto\"|\n\x15GetTransactionRequest\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x12\x0e\n\x06\x62inary\x18\x02 \x01(\x08\x12\x32\n\x0cledger_range\x18\x03 \x01(\x0b\x32\x1c.org.xrpl.rpc.v1.LedgerRange\x12\x11\n\tclient_ip\x18\x04 \x01(\t\"\xb2\x02\n\x16GetTransactionResponse\x12\x33\n\x0btransaction\x18\x01 \x01(\x0b\x32\x1c.org.xrpl.rpc.v1.TransactionH\x00\x12\x1c\n\x12transaction_binary\x18\x02 \x01(\x0cH\x00\x12\x14\n\x0cledger_index\x18\x03 \x01(\r\x12\x0c\n\x04hash\x18\x04 \x01(\x0c\x12\x11\n\tvalidated\x18\x05 \x01(\x08\x12%\n\x04meta\x18\x06 \x01(\x0b\x32\x15.org.xrpl.rpc.v1.MetaH\x01\x12\x15\n\x0bmeta_binary\x18\x07 \x01(\x0cH\x01\x12#\n\x04\x64\x61te\x18\x08 \x01(\x0b\x32\x15.org.xrpl.rpc.v1.DateB\x18\n\x16serialized_transactionB\x11\n\x0fserialized_metaB\x13\n\x0forg.xrpl.rpc.v1P\x01\x62\x06proto3'
  ,
  dependencies=[org_dot_xrpl_dot_rpc_dot_v1_dot_meta__pb2.DESCRIPTOR,org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__pb2.DESCRIPTOR,org_dot_xrpl_dot_rpc_dot_v1_dot_transaction__pb2.DESCRIPTOR,org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2.DESCRIPTOR,])




_GETTRANSACTIONREQUEST = _descriptor.Descriptor(
  name='GetTransactionRequest',
  full_name='org.xrpl.rpc.v1.GetTransactionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hash', full_name='org.xrpl.rpc.v1.GetTransactionRequest.hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='binary', full_name='org.xrpl.rpc.v1.GetTransactionRequest.binary', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ledger_range', full_name='org.xrpl.rpc.v1.GetTransactionRequest.ledger_range', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_ip', full_name='org.xrpl.rpc.v1.GetTransactionRequest.client_ip', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=181,
  serialized_end=305,
)


_GETTRANSACTIONRESPONSE = _descriptor.Descriptor(
  name='GetTransactionResponse',
  full_name='org.xrpl.rpc.v1.GetTransactionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transaction', full_name='org.xrpl.rpc.v1.GetTransactionResponse.transaction', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transaction_binary', full_name='org.xrpl.rpc.v1.GetTransactionResponse.transaction_binary', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ledger_index', full_name='org.xrpl.rpc.v1.GetTransactionResponse.ledger_index', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hash', full_name='org.xrpl.rpc.v1.GetTransactionResponse.hash', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validated', full_name='org.xrpl.rpc.v1.GetTransactionResponse.validated', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='meta', full_name='org.xrpl.rpc.v1.GetTransactionResponse.meta', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='meta_binary', full_name='org.xrpl.rpc.v1.GetTransactionResponse.meta_binary', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date', full_name='org.xrpl.rpc.v1.GetTransactionResponse.date', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='serialized_transaction', full_name='org.xrpl.rpc.v1.GetTransactionResponse.serialized_transaction',
      index=0, containing_type=None, fields=[]),
    _descriptor.OneofDescriptor(
      name='serialized_meta', full_name='org.xrpl.rpc.v1.GetTransactionResponse.serialized_meta',
      index=1, containing_type=None, fields=[]),
  ],
  serialized_start=308,
  serialized_end=614,
)

_GETTRANSACTIONREQUEST.fields_by_name['ledger_range'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__pb2._LEDGERRANGE
_GETTRANSACTIONRESPONSE.fields_by_name['transaction'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_transaction__pb2._TRANSACTION
_GETTRANSACTIONRESPONSE.fields_by_name['meta'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_meta__pb2._META
_GETTRANSACTIONRESPONSE.fields_by_name['date'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._DATE
_GETTRANSACTIONRESPONSE.oneofs_by_name['serialized_transaction'].fields.append(
  _GETTRANSACTIONRESPONSE.fields_by_name['transaction'])
_GETTRANSACTIONRESPONSE.fields_by_name['transaction'].containing_oneof = _GETTRANSACTIONRESPONSE.oneofs_by_name['serialized_transaction']
_GETTRANSACTIONRESPONSE.oneofs_by_name['serialized_transaction'].fields.append(
  _GETTRANSACTIONRESPONSE.fields_by_name['transaction_binary'])
_GETTRANSACTIONRESPONSE.fields_by_name['transaction_binary'].containing_oneof = _GETTRANSACTIONRESPONSE.oneofs_by_name['serialized_transaction']
_GETTRANSACTIONRESPONSE.oneofs_by_name['serialized_meta'].fields.append(
  _GETTRANSACTIONRESPONSE.fields_by_name['meta'])
_GETTRANSACTIONRESPONSE.fields_by_name['meta'].containing_oneof = _GETTRANSACTIONRESPONSE.oneofs_by_name['serialized_meta']
_GETTRANSACTIONRESPONSE.oneofs_by_name['serialized_meta'].fields.append(
  _GETTRANSACTIONRESPONSE.fields_by_name['meta_binary'])
_GETTRANSACTIONRESPONSE.fields_by_name['meta_binary'].containing_oneof = _GETTRANSACTIONRESPONSE.oneofs_by_name['serialized_meta']
DESCRIPTOR.message_types_by_name['GetTransactionRequest'] = _GETTRANSACTIONREQUEST
DESCRIPTOR.message_types_by_name['GetTransactionResponse'] = _GETTRANSACTIONRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetTransactionRequest = _reflection.GeneratedProtocolMessageType('GetTransactionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTRANSACTIONREQUEST,
  '__module__' : 'org.xrpl.rpc.v1.get_transaction_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.GetTransactionRequest)
  })
_sym_db.RegisterMessage(GetTransactionRequest)

GetTransactionResponse = _reflection.GeneratedProtocolMessageType('GetTransactionResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTRANSACTIONRESPONSE,
  '__module__' : 'org.xrpl.rpc.v1.get_transaction_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.GetTransactionResponse)
  })
_sym_db.RegisterMessage(GetTransactionResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
