# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: org/xrpl/rpc/v1/get_ledger_diff.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import ledger_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='org/xrpl/rpc/v1/get_ledger_diff.proto',
  package='org.xrpl.rpc.v1',
  syntax='proto3',
  serialized_options=b'\n\017org.xrpl.rpc.v1P\001',
  serialized_pb=b'\n%org/xrpl/rpc/v1/get_ledger_diff.proto\x12\x0forg.xrpl.rpc.v1\x1a\x1corg/xrpl/rpc/v1/ledger.proto\"\xb1\x01\n\x14GetLedgerDiffRequest\x12\x35\n\x0b\x62\x61se_ledger\x18\x01 \x01(\x0b\x32 .org.xrpl.rpc.v1.LedgerSpecifier\x12\x38\n\x0e\x64\x65sired_ledger\x18\x02 \x01(\x0b\x32 .org.xrpl.rpc.v1.LedgerSpecifier\x12\x15\n\rinclude_blobs\x18\x03 \x01(\x08\x12\x11\n\tclient_ip\x18\x04 \x01(\t\"R\n\x15GetLedgerDiffResponse\x12\x39\n\x0eledger_objects\x18\x01 \x01(\x0b\x32!.org.xrpl.rpc.v1.RawLedgerObjectsB\x13\n\x0forg.xrpl.rpc.v1P\x01\x62\x06proto3'
  ,
  dependencies=[org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__pb2.DESCRIPTOR,])




_GETLEDGERDIFFREQUEST = _descriptor.Descriptor(
  name='GetLedgerDiffRequest',
  full_name='org.xrpl.rpc.v1.GetLedgerDiffRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base_ledger', full_name='org.xrpl.rpc.v1.GetLedgerDiffRequest.base_ledger', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='desired_ledger', full_name='org.xrpl.rpc.v1.GetLedgerDiffRequest.desired_ledger', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='include_blobs', full_name='org.xrpl.rpc.v1.GetLedgerDiffRequest.include_blobs', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_ip', full_name='org.xrpl.rpc.v1.GetLedgerDiffRequest.client_ip', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=89,
  serialized_end=266,
)


_GETLEDGERDIFFRESPONSE = _descriptor.Descriptor(
  name='GetLedgerDiffResponse',
  full_name='org.xrpl.rpc.v1.GetLedgerDiffResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ledger_objects', full_name='org.xrpl.rpc.v1.GetLedgerDiffResponse.ledger_objects', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=268,
  serialized_end=350,
)

_GETLEDGERDIFFREQUEST.fields_by_name['base_ledger'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__pb2._LEDGERSPECIFIER
_GETLEDGERDIFFREQUEST.fields_by_name['desired_ledger'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__pb2._LEDGERSPECIFIER
_GETLEDGERDIFFRESPONSE.fields_by_name['ledger_objects'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__pb2._RAWLEDGEROBJECTS
DESCRIPTOR.message_types_by_name['GetLedgerDiffRequest'] = _GETLEDGERDIFFREQUEST
DESCRIPTOR.message_types_by_name['GetLedgerDiffResponse'] = _GETLEDGERDIFFRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetLedgerDiffRequest = _reflection.GeneratedProtocolMessageType('GetLedgerDiffRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLEDGERDIFFREQUEST,
  '__module__' : 'org.xrpl.rpc.v1.get_ledger_diff_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.GetLedgerDiffRequest)
  })
_sym_db.RegisterMessage(GetLedgerDiffRequest)

GetLedgerDiffResponse = _reflection.GeneratedProtocolMessageType('GetLedgerDiffResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETLEDGERDIFFRESPONSE,
  '__module__' : 'org.xrpl.rpc.v1.get_ledger_diff_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.GetLedgerDiffResponse)
  })
_sym_db.RegisterMessage(GetLedgerDiffResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
