# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from .ledger_pb2 import (
    LedgerSpecifier as org___xrpl___rpc___v1___ledger_pb2___LedgerSpecifier,
    RawLedgerObject as org___xrpl___rpc___v1___ledger_pb2___RawLedgerObject,
)

from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
    Union as typing___Union,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int
if sys.version_info < (3,):
    builtin___buffer = buffer
    builtin___unicode = unicode


DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class GetLedgerEntryRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    key: builtin___bytes = ...
    client_ip: typing___Text = ...

    @property
    def ledger(self) -> org___xrpl___rpc___v1___ledger_pb2___LedgerSpecifier: ...

    def __init__(self,
        *,
        key : typing___Optional[builtin___bytes] = None,
        ledger : typing___Optional[org___xrpl___rpc___v1___ledger_pb2___LedgerSpecifier] = None,
        client_ip : typing___Optional[typing___Text] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> GetLedgerEntryRequest: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> GetLedgerEntryRequest: ...
    def HasField(self, field_name: typing_extensions___Literal[u"ledger",b"ledger"]) -> builtin___bool: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"client_ip",b"client_ip",u"key",b"key",u"ledger",b"ledger"]) -> None: ...
type___GetLedgerEntryRequest = GetLedgerEntryRequest

class GetLedgerEntryResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def ledger_object(self) -> org___xrpl___rpc___v1___ledger_pb2___RawLedgerObject: ...

    @property
    def ledger(self) -> org___xrpl___rpc___v1___ledger_pb2___LedgerSpecifier: ...

    def __init__(self,
        *,
        ledger_object : typing___Optional[org___xrpl___rpc___v1___ledger_pb2___RawLedgerObject] = None,
        ledger : typing___Optional[org___xrpl___rpc___v1___ledger_pb2___LedgerSpecifier] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> GetLedgerEntryResponse: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> GetLedgerEntryResponse: ...
    def HasField(self, field_name: typing_extensions___Literal[u"ledger",b"ledger",u"ledger_object",b"ledger_object"]) -> builtin___bool: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"ledger",b"ledger",u"ledger_object",b"ledger_object"]) -> None: ...
type___GetLedgerEntryResponse = GetLedgerEntryResponse
